@@ -45,21 +45,35 @@ enum
 	FLT_RANGE_THISQUARTER = 2,
 	FLT_RANGE_LASTQUARTER = 3,
 	FLT_RANGE_THISYEAR = 4,
-	
-	FLT_RANGE_LAST30DAYS = 6,
-	FLT_RANGE_LAST60DAYS = 7,
-	FLT_RANGE_LAST90DAYS = 8,
-	FLT_RANGE_LAST12MONTHS = 9,
-	
-	FLT_RANGE_OTHER = 11,
-	
-	FLT_RANGE_ALLDATE = 13
+	FLT_RANGE_LASTYEAR = 5,	 //was not existing on 4.5
+	// 6 separator
+	FLT_RANGE_LAST30DAYS = 7,
+	FLT_RANGE_LAST60DAYS = 8,
+	FLT_RANGE_LAST90DAYS = 9,
+	FLT_RANGE_LAST12MONTHS = 10,
+	// 11 separator
+	FLT_RANGE_OTHER = 12,
+	// 13 separator
+	FLT_RANGE_ALLDATE = 14
 };
 
-//default settings for account window
-#define FLT_TYPE_ALL 3
-#define FLT_STATUS_ALL 3
 
+enum
+{
+	FLT_TYPE_EXPENSE = 0,
+	FLT_TYPE_INCOME = 1,
+	// 2 separator
+	FLT_TYPE_ALL = 3
+};
+
+
+enum
+{
+	FLT_STATUS_UNCATEGORIZED = 0,
+	FLT_STATUS_UNRECONCILED = 1,
+	// 2 separator
+	FLT_STATUS_ALL = 3
+};
 
 typedef struct _filter	Filter;
 
