@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2013 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -34,4 +34,4 @@ enum
 	NUM_LST_DSPUPC
 };
 
-#endif /* __LIST_UPCOMING__H__ */
+#endif
\ No newline at end of file
