@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2013 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -17,8 +17,8 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __HB_UI_ASSIST_START_H__
-#define __HB_UI_ASSIST_START_H__
+#ifndef __HB_UI_ASSIST_START_GTK_H__
+#define __HB_UI_ASSIST_START_GTK_H__
 
 
 struct assist_start_data
@@ -26,7 +26,7 @@ struct assist_start_data
 	GtkWidget	*assistant;
 	//GtkWidget	*pages[NUM_PAGE];
 	GtkWidget	*ST_owner;
-	
+
 	GtkWidget	*TX_lang;
 	GtkWidget	*TX_file;
 	GtkWidget	*ok_image, *ko_image;
@@ -41,9 +41,9 @@ struct assist_start_data
 	gchar *pathfilename;
 };
 
-	
+
 
 GtkWidget *ui_start_assistant(void);
-	
-	
-#endif /* __HB_UI_ASSIST_START__ */
+
+
+#endif
